@@ -311,6 +311,7 @@ class DockedApp(object):
         icon_filename : the filename of the app icon
         desktop_file : the filename of the app's .desktop file
         wm_class_name:
+        wm_class_group_name:
         applet_win  : the Gdk.Window of the panel applet
         applet_orient : the applet orientation
 
@@ -361,6 +362,7 @@ class DockedApp(object):
         self.icon_filename = ""
         self.desktop_file = ""
         self.wm_class_name = ""
+        self.wm_class_group_name = ""
         self.icon_geometry_set = False
         self.applet_win = None
         self.applet_orient = None
@@ -452,6 +454,8 @@ class DockedApp(object):
             win.connect("state-changed", self.win_state_changed)
             win_class = win.get_class_group()
             win_class_name = win_class.get_res_class()
+            #if self.wm_class_group_name == "":
+            #    self.wm_class_group_name = win.get_class_group_name()
 
             if ((win.get_window_type() == Wnck.WindowType.NORMAL) or
                     (win.get_window_type() == Wnck.WindowType.DIALOG)) and \
@@ -565,6 +569,18 @@ class DockedApp(object):
 
         return win_list
 
+    def get_first_window(self):
+        """ Return the first window the app has open
+
+        Returns: a wnck.window, or None (if the app has no open windows)
+        """
+
+        if self.get_num_windows() == 0:
+            return None
+        else:
+            win_list = self.get_wnck_windows()
+            return win_list[0]
+
     def has_windows_on_workspace(self, wnck_workspace):
         """ test whether the app has at least one window open on a specified
             workspace
@@ -1288,17 +1304,18 @@ class DockedApp(object):
         # to calculate it's position based on the notional DA_SIZE
         #
 
-        left = draw_size - width + inset
+        adj = 2
+        left = draw_size - width + inset - adj
 
         # do the drawing - attribution for the drawing code:
         # https://bazaar.launchpad.net/~unity-team/unity/trunk/view/head:/launcher/LauncherIcon.cpp
         ctx.scale(self.drawing_area_size/draw_size,
                   self.drawing_area_size/draw_size)
 
-        ctx.move_to(left, height-1)
-        ctx.arc(left, inset, radius, 0.5 * math.pi, 1.5*math.pi)
-        ctx.arc(draw_size-inset, inset, radius, 1.5*math.pi, 0.5*math.pi)
-        ctx.line_to(left, height-1)
+        ctx.move_to(left, height - 1+ adj)
+        ctx.arc(left, inset + adj, radius, 0.5 * math.pi, 1.5*math.pi)
+        ctx.arc(draw_size-inset-adj, inset + adj, radius, 1.5*math.pi, 0.5*math.pi)
+        ctx.line_to(left, height - 1 + adj)
         ctx.set_source_rgb(bred, bgreen, bblue)
         ctx.fill_preserve()
         ctx.set_source_rgb(tred, tgreen, tblue)
@@ -1307,7 +1324,7 @@ class DockedApp(object):
 
         # draw the text
         ctx.move_to(left - inset + width/2 - (extents[0]+extents[2]/2),
-                    (height/2)+extents[3]/2)
+                    (height/2) + adj +extents[3]/2)
         ctx.set_source_rgb(tred, tgreen, tblue)
         ctx.show_text(ctext)
 
